SmartAuthResult<T> class
The result returned from SmartAuth methods
Constructors
- SmartAuthResult.canceled()
-
const
- SmartAuthResult.failure(Object? error)
-
const
- SmartAuthResult.success(T? data)
-
const
Properties
- data → T?
-
The data object if
stateis SmartAuthResultState.successfinal - error → Object?
-
The error object if
stateis SmartAuthResultState.failurefinal - hasData → bool
-
Returns whether result contains a non-null data value.
no setter
- hasError → bool
-
Returns whether result contains a non-null error value.
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- isCanceled → bool
-
Returns whether user canceled the operation.
no setter
- requireData → T
-
Returns latest data received, failing if there is no data.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override